@@ -60,11 +60,11 @@ class RelationPublishedQueryset(models.QuerySet):
             if not ann_proj:
                 return qs
             users_show = request.session.get('users_show_highlighter', None)
-        query = Q(annotation__annotation_project_id=ann_proj)
+        query = Q(annotation_set__annotation_project_id=ann_proj)
         if users_show is not None:
-            query.add(Q(annotation__user_added_id__in=users_show), Q.AND)
+            query.add(Q(annotation_set__user_added_id__in=users_show), Q.AND)
         if include_all:
-            query.add(Q(annotation__annotation_project__isnull=True), Q.OR)
+            query.add(Q(annotation_set__annotation_project__isnull=True), Q.OR)
         return qs.filter(query)
 
 
