@@ -1,6 +1,6 @@
 from django.conf.urls import url
 
-from . tei_ac import TeiEntAc
+from .tei_ac import TeiEntAc, TeiCompleterAc
 
 app_name = 'apis_tei'
 
@@ -10,4 +10,9 @@ urlpatterns = [
         TeiEntAc.as_view(),
         name='generic_entities_autocomplete'
     ),
+    url(
+        r'^tei-completer/(?P<entity>[a-zA-Z0-9-]+)/$',
+        TeiCompleterAc.as_view(),
+        name='tei_completer_autocomplete'
+    ),
 ]
